@@ -16,7 +16,7 @@ from bugbug import db, utils
 BUGS_DB = "data/bugs.json"
 db.register(
     BUGS_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_bugs.latest/artifacts/public/bugs.json.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_bugs.latest/artifacts/public/bugs.json.zst",
     6,
 )
 
@@ -237,7 +237,7 @@ def get_product_component_csv_report():
 
 
 def get_product_component_count():
-    """ Returns a dictionary where keys are full components (in the form of
+    """Returns a dictionary where keys are full components (in the form of
     `{product}::{component}`) and the value of the number of bugs for the
     given full components. Full component with 0 bugs are returned.
     """
