@@ -9,9 +9,23 @@ from bugbug.models.defect import DefectModel
 class RegressionModel(DefectModel):
     def __init__(self, lemmatization=False, historical=False):
         DefectModel.__init__(self, lemmatization, historical)
+        self.calculate_importance = False
 
     def get_labels(self):
-        return self.get_bugbug_labels("regression"), [0, 1]
+        classes = self.get_bugbug_labels("regression")
+
+        print(
+            "{} regression bugs".format(
+                sum(1 for label in classes.values() if label == 1)
+            )
+        )
+        print(
+            "{} non-regression bugs".format(
+                sum(1 for label in classes.values() if label == 0)
+            )
+        )
+
+        return classes, [0, 1]
 
     def overwrite_classes(self, bugs, classes, probabilities):
         for i, bug in enumerate(bugs):
