@@ -142,9 +142,6 @@ class TestSelectModel(Model):
             for test_data in test_datas:
                 name = test_data["name"]
 
-                if self.granularity == "label" and not name.startswith("test-"):
-                    continue
-
                 if (
                     test_data["is_likely_regression"]
                     or test_data["is_possible_regression"]
@@ -158,7 +155,11 @@ class TestSelectModel(Model):
                     continue
 
             pushes.append(
-                {"revs": revs, "failures": failures, "passes": passes,}
+                {
+                    "revs": revs,
+                    "failures": failures,
+                    "passes": passes,
+                }
             )
 
         return pushes, math.floor(0.9 * len(pushes))
@@ -185,8 +186,7 @@ class TestSelectModel(Model):
             commits = tuple(
                 commit_map.pop(revision) for revision in revs if revision in commit_map
             )
-            if len(commits) == 0:
-                continue
+            assert len(commits) > 0
 
             for test_data in test_datas:
                 name = test_data["name"]
@@ -242,9 +242,6 @@ class TestSelectModel(Model):
             push_num = past_failures_data["push_num"] + 1
         all_runnables = past_failures_data["all_runnables"]
 
-        if self.granularity == "label":
-            all_runnables = tuple(r for r in all_runnables if r.startswith("test-"))
-
         commit_tests = []
         for data in test_scheduling.generate_data(
             self.granularity,
@@ -268,6 +265,8 @@ class TestSelectModel(Model):
 
     def _get_cost(self, config: str) -> int:
         costs = [
+            (("build", "opt"), 1),
+            (("build", "debug"), 2),
             (("linux1804-64", "opt"), 2),
             (("linux1804-64", "debug"), 3),
             (("windows10", "opt"), 4),
@@ -792,7 +791,12 @@ def eval_apply_transforms(model, push, confidence_threshold, reduction, cap, min
             selected = model.reduce(selected, reduction)
         elif model.granularity == "group":
             number_configs = len(
-                set(sum(model.select_configs(selected, reduction).values(), [],))
+                set(
+                    sum(
+                        model.select_configs(selected, reduction).values(),
+                        [],
+                    )
+                )
             )
 
     if minimum is not None and len(selected) < minimum:
