@@ -18,11 +18,23 @@ import sys
 import threading
 from datetime import datetime
 from functools import lru_cache
-from typing import Generator, Iterable, List, NewType, Optional, Tuple
+from typing import (
+    Collection,
+    Dict,
+    Generator,
+    Iterable,
+    List,
+    NewType,
+    Optional,
+    Set,
+    Tuple,
+    Union,
+)
 
 import hglib
 import lmdb
 import rs_parsepatch
+import tenacity
 from tqdm import tqdm
 
 from bugbug import db, rust_code_analysis_server, utils
@@ -42,8 +54,8 @@ COMMITS_DB = "data/commits.json"
 COMMIT_EXPERIENCES_DB = "commit_experiences.lmdb.tar.zst"
 db.register(
     COMMITS_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_commits.latest/artifacts/public/commits.json.zst",
-    13,
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_commits.latest/artifacts/public/commits.json.zst",
+    14,
     [COMMIT_EXPERIENCES_DB],
 )
 
@@ -109,23 +121,21 @@ def get_type(path: str) -> str:
 class Commit:
     def __init__(
         self,
-        node,
-        author,
-        desc,
-        date,
-        pushdate,
-        bug_id,
-        backsout,
-        backedoutby,
-        author_email,
-        reviewers,
-        ignored=False,
-    ):
+        node: str,
+        author: str,
+        desc: str,
+        pushdate: datetime,
+        bug_id: Optional[int],
+        backsout: List[str],
+        backedoutby: str,
+        author_email: str,
+        reviewers: List[str],
+        ignored: bool = False,
+    ) -> None:
         self.node = node
         self.author = author
         self.bug_id = bug_id
         self.desc = desc
-        self.date = date
         self.pushdate = pushdate
         self.backsout = backsout
         self.backedoutby = backedoutby
@@ -138,21 +148,21 @@ class Commit:
         self.source_code_deleted = 0
         self.other_deleted = 0
         self.test_deleted = 0
-        self.types = set()
-        self.functions = {}
+        self.types: Set[str] = set()
+        self.functions: Dict[str, List[Tuple[str, int, int]]] = {}
         self.seniority_author = 0.0
         self.total_source_code_file_size = 0
-        self.average_source_code_file_size = 0
+        self.average_source_code_file_size = 0.0
         self.maximum_source_code_file_size = 0
         self.minimum_source_code_file_size = 0
         self.source_code_files_modified_num = 0
         self.total_other_file_size = 0
-        self.average_other_file_size = 0
+        self.average_other_file_size = 0.0
         self.maximum_other_file_size = 0
         self.minimum_other_file_size = 0
         self.other_files_modified_num = 0
         self.total_test_file_size = 0
-        self.average_test_file_size = 0
+        self.average_test_file_size = 0.0
         self.maximum_test_file_size = 0
         self.minimum_test_file_size = 0
         self.test_files_modified_num = 0
@@ -192,6 +202,9 @@ class Commit:
     def __hash__(self):
         return hash(self.node)
 
+    def __repr__(self):
+        return str(self.__dict__)
+
     def set_files(self, files, file_copies):
         self.files = files
         self.file_copies = file_copies
@@ -222,7 +235,6 @@ class Commit:
             del d[f]
         d["types"] = list(d["types"])
         d["pushdate"] = str(d["pushdate"])
-        d["date"] = str(d["date"])
         return CommitDict(d)
 
 
@@ -432,13 +444,15 @@ def get_metrics(commit, metrics_space):
             commit.maximum_cyclomatic, metrics["cyclomatic"]
         )
         commit.maximum_halstead_n2 = max(
-            commit.maximum_halstead_n2, metrics["halstead"]["n2"],
+            commit.maximum_halstead_n2,
+            metrics["halstead"]["n2"],
         )
         commit.maximum_halstead_N2 = max(
             metrics["halstead"]["N2"], commit.maximum_halstead_N2
         )
         commit.maximum_halstead_n1 = max(
-            metrics["halstead"]["n1"], commit.maximum_halstead_n1,
+            metrics["halstead"]["n1"],
+            commit.maximum_halstead_n1,
         )
         commit.maximum_halstead_N1 = max(
             metrics["halstead"]["N1"], commit.maximum_halstead_N1
@@ -454,13 +468,15 @@ def get_metrics(commit, metrics_space):
             commit.minimum_cyclomatic, metrics["cyclomatic"]
         )
         commit.minimum_halstead_n2 = min(
-            commit.minimum_halstead_n2, metrics["halstead"]["n2"],
+            commit.minimum_halstead_n2,
+            metrics["halstead"]["n2"],
         )
         commit.minimum_halstead_N2 = min(
             metrics["halstead"]["N2"], commit.minimum_halstead_N2
         )
         commit.minimum_halstead_n1 = min(
-            metrics["halstead"]["n1"], commit.minimum_halstead_n1,
+            metrics["halstead"]["n1"],
+            commit.minimum_halstead_n1,
         )
         commit.minimum_halstead_N1 = min(
             metrics["halstead"]["N1"], commit.minimum_halstead_N1
@@ -626,37 +642,41 @@ def _transform(commit):
 
 
 def hg_log(hg: hglib.client, revs: List[bytes]) -> List[Commit]:
-    template = "{node}\\0{author}\\0{desc}\\0{date|hgdate}\\0{bug}\\0{backedoutby}\\0{author|email}\\0{pushdate|hgdate}\\0{reviewers}\\0{backsoutnodes}\\0"
+    if len(revs) == 0:
+        return []
+
+    template = "{node}\\0{author}\\0{desc}\\0{bug}\\0{backedoutby}\\0{author|email}\\0{pushdate|hgdate}\\0{reviewers}\\0{backsoutnodes}\\0"
 
     args = hglib.util.cmdbuilder(
-        b"log", template=template, no_merges=True, rev=revs, branch="tip",
+        b"log",
+        template=template,
+        no_merges=True,
+        rev=revs,
+        branch="tip",
     )
     x = hg.rawcommand(args)
     out = x.split(b"\x00")[:-1]
 
     commits = []
     for rev in hglib.util.grouper(template.count("\\0"), out):
-        assert b" " in rev[3]
-        date = datetime.utcfromtimestamp(float(rev[3].split(b" ", 1)[0]))
-
-        assert b" " in rev[7]
-        pushdate_timestamp = rev[7].split(b" ", 1)[0]
+        assert b" " in rev[6]
+        pushdate_timestamp = rev[6].split(b" ", 1)[0]
         if pushdate_timestamp != b"0":
             pushdate = datetime.utcfromtimestamp(float(pushdate_timestamp))
         else:
             pushdate = datetime.utcnow()
 
-        bug_id = int(rev[4].decode("ascii")) if rev[4] else None
+        bug_id = int(rev[3].decode("ascii")) if rev[3] else None
 
         reviewers = (
-            list(set(sys.intern(r) for r in rev[8].decode("utf-8").split(" ")))
-            if rev[8] != b""
+            list(set(sys.intern(r) for r in rev[7].decode("utf-8").split(" ")))
+            if rev[7] != b""
             else []
         )
 
         backsout = (
-            list(set(sys.intern(r) for r in rev[9].decode("utf-8").split(" ")))
-            if rev[9] != b""
+            list(set(sys.intern(r) for r in rev[8].decode("utf-8").split(" ")))
+            if rev[8] != b""
             else []
         )
 
@@ -665,12 +685,11 @@ def hg_log(hg: hglib.client, revs: List[bytes]) -> List[Commit]:
                 node=sys.intern(rev[0].decode("ascii")),
                 author=sys.intern(rev[1].decode("utf-8")),
                 desc=rev[2].decode("utf-8"),
-                date=date,
                 pushdate=pushdate,
                 bug_id=bug_id,
                 backsout=backsout,
-                backedoutby=rev[5].decode("ascii"),
-                author_email=rev[6].decode("utf-8"),
+                backedoutby=rev[4].decode("ascii"),
+                author_email=rev[5].decode("utf-8"),
                 reviewers=reviewers,
             )
         )
@@ -738,7 +757,9 @@ class Experiences:
             self.mem_experiences[key] = value
 
 
-def calculate_experiences(commits, first_pushdate, save=True):
+def calculate_experiences(
+    commits: Collection[Commit], first_pushdate: datetime, save: bool = True
+) -> None:
     logger.info(f"Analyzing seniorities from {len(commits)} commits...")
 
     experiences = Experiences(save)
@@ -759,10 +780,12 @@ def calculate_experiences(commits, first_pushdate, save=True):
     # "dir1" and a commit C which modifies "dir1" and "dir2". The number of previous commits touching the same directories
     # for C should be 2 (A + B), and not 3 (A twice + B).
 
-    def get_key(exp_type, commit_type, item):
+    def get_key(exp_type: str, commit_type: str, item: str) -> str:
         return f"{exp_type}${commit_type}${item}"
 
-    def get_experience(exp_type, commit_type, item, day, default):
+    def get_experience(
+        exp_type: str, commit_type: str, item: str, day: int, default: Union[int, Tuple]
+    ) -> utils.ExpQueue:
         key = get_key(exp_type, commit_type, item)
         try:
             return experiences[key]
@@ -771,7 +794,9 @@ def calculate_experiences(commits, first_pushdate, save=True):
             experiences[key] = queue
             return queue
 
-    def update_experiences(experience_type, day, items):
+    def update_experiences(
+        experience_type: str, day: int, items: Collection[str]
+    ) -> None:
         for commit_type in ("", "backout"):
             exp_queues = tuple(
                 get_experience(experience_type, commit_type, item, day, 0)
@@ -813,7 +838,9 @@ def calculate_experiences(commits, first_pushdate, save=True):
                 for i in range(len(items)):
                     exp_queues[i][day] = total_exps[i] + 1
 
-    def update_complex_experiences(experience_type, day, items):
+    def update_complex_experiences(
+        experience_type: str, day: int, items: Collection[str]
+    ) -> None:
         for commit_type in ("", "backout"):
             exp_queues = tuple(
                 get_experience(experience_type, commit_type, item, day, tuple())
@@ -878,18 +905,12 @@ def calculate_experiences(commits, first_pushdate, save=True):
                 for i in range(len(items)):
                     exp_queues[i][day] = all_commit_lists[i] + (commit.node,)
 
-    # prev_day = 0
-    # prev_commit = None
     for i, commit in enumerate(tqdm(commits)):
+        # The push date is unreliable, e.g. 4d0e3037210dd03bdb21964a6a8c2e201c45794b was pushed after
+        # 06b578dfadc9db8b683090e0e110ba75b84fb766, but it has an earlier push date.
+        # We accept the unreliability as it is small enough.
         day = (commit.pushdate - first_pushdate).days
         assert day >= 0
-        # TODO: Bring back this assertion, but using pushid instead.
-        # pushdate is unreliable, e.g. 4d0e3037210dd03bdb21964a6a8c2e201c45794b was pushed after 06b578dfadc9db8b683090e0e110ba75b84fb766, but it has an earlier push date...
-        # assert (
-        #     day >= prev_day
-        # ), f"Commit {commit.node} pushed on {commit.pushdate} should come after {prev_commit.node} pushed on {prev_commit.pushdate}"
-        # prev_day = day
-        # prev_commit = commit
 
         # When a file is moved/copied, copy original experience values to the copied path.
         for orig, copied in commit.file_copies.items():
@@ -1005,9 +1026,10 @@ def download_commits(
     with hglib.open(repo_dir) as hg:
         if revs is None:
             revs = get_revs(hg, rev_start)
-            if len(revs) == 0:
-                logger.info("No commits to analyze")
-                return tuple()
+
+        if len(revs) == 0:
+            logger.info("No commits to analyze")
+            return tuple()
 
         first_pushdate = get_first_pushdate(repo_dir)
 
@@ -1082,12 +1104,16 @@ def clean(hg, repo_dir):
             raise
 
 
-def _run_hg_cmd(repo_dir, cmd, *args, **kwargs):
-    cmd = hglib.util.cmdbuilder(cmd, *args, **kwargs,)
+def _build_hg_cmd(cmd, *args, **kwargs):
+    cmd = hglib.util.cmdbuilder(
+        cmd,
+        *args,
+        **kwargs,
+    )
 
     cmd.insert(0, hglib.HGPATH)
 
-    subprocess.run(cmd, cwd=repo_dir, check=True)
+    return cmd
 
 
 def clone(
@@ -1116,8 +1142,7 @@ def clone(
         if "abort: repository" not in str(e) and "not found" not in str(e):
             raise
 
-    _run_hg_cmd(
-        None,
+    cmd = _build_hg_cmd(
         "robustcheckout",
         url,
         repo_dir,
@@ -1127,6 +1152,7 @@ def clone(
         branch=b"tip",
         noupdate=not update,
     )
+    subprocess.run(cmd, check=True)
 
     logger.info(f"{repo_dir} cloned")
 
@@ -1134,20 +1160,35 @@ def clone(
 def pull(repo_dir: str, branch: str, revision: str) -> None:
     """Pull a revision from a branch of a remote repository into a local repository"""
 
-    def do_pull() -> None:
-        _run_hg_cmd(
-            repo_dir,
+    @tenacity.retry(
+        stop=tenacity.stop_after_attempt(2),
+        reraise=True,
+        after=tenacity.after_log(logger, logging.DEBUG),
+        retry=tenacity.retry_if_exception_type(subprocess.TimeoutExpired),
+    )
+    def trigger_pull() -> None:
+        cmd = _build_hg_cmd(
             "pull",
             f"https://hg.mozilla.org/{branch}/".encode("ascii"),
             r=revision.encode("ascii"),
             debug=True,
         )
 
-    try:
-        do_pull()
-    except subprocess.CalledProcessError:
-        _run_hg_cmd(repo_dir, "recover")
-        do_pull()
+        p = subprocess.Popen(cmd, cwd=repo_dir)
+
+        try:
+            p.wait(timeout=180)
+        except subprocess.TimeoutExpired:
+            p.terminate()
+            p.wait()
+            raise
+
+        if p.returncode != 0:
+            raise Exception(
+                f"Error {p.returncode} when pulling {revision} from {branch}"
+            )
+
+    trigger_pull()
 
 
 if __name__ == "__main__":
