@@ -54,14 +54,14 @@ PAST_FAILURES_LABEL_DB = "past_failures_label.lmdb.tar.zst"
 FAILING_TOGETHER_LABEL_DB = "failing_together_label.lmdb.tar.zst"
 db.register(
     TEST_LABEL_SCHEDULING_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_test_label_scheduling_history.latest/artifacts/public/test_label_scheduling_history.pickle.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_test_label_scheduling_history.latest/artifacts/public/test_label_scheduling_history.pickle.zst",
     13,
     [PAST_FAILURES_LABEL_DB, FAILING_TOGETHER_LABEL_DB],
 )
 PUSH_DATA_LABEL_DB = "data/push_data_label.json"
 db.register(
     PUSH_DATA_LABEL_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_test_label_scheduling_history_push_data.latest/artifacts/public/push_data_label.json.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_test_label_scheduling_history_push_data.latest/artifacts/public/push_data_label.json.zst",
     1,
 )
 
@@ -70,14 +70,14 @@ PAST_FAILURES_GROUP_DB = "past_failures_group.lmdb.tar.zst"
 TOUCHED_TOGETHER_DB = "touched_together.lmdb.tar.zst"
 db.register(
     TEST_GROUP_SCHEDULING_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_test_group_scheduling_history.latest/artifacts/public/test_group_scheduling_history.pickle.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_test_group_scheduling_history.latest/artifacts/public/test_group_scheduling_history.pickle.zst",
     1,
     [PAST_FAILURES_GROUP_DB, TOUCHED_TOGETHER_DB],
 )
 PUSH_DATA_GROUP_DB = "data/push_data_group.json"
 db.register(
     PUSH_DATA_GROUP_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_test_group_scheduling_history_push_data.latest/artifacts/public/push_data_group.json.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_test_group_scheduling_history_push_data.latest/artifacts/public/push_data_group.json.zst",
     1,
 )
 
@@ -86,14 +86,14 @@ PAST_FAILURES_CONFIG_GROUP_DB = "past_failures_config_group.lmdb.tar.zst"
 FAILING_TOGETHER_CONFIG_GROUP_DB = "failing_together_config_group.lmdb.tar.zst"
 db.register(
     TEST_CONFIG_GROUP_SCHEDULING_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_test_config_group_scheduling_history.latest/artifacts/public/test_config_group_scheduling_history.pickle.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_test_config_group_scheduling_history.latest/artifacts/public/test_config_group_scheduling_history.pickle.zst",
     20,
     [PAST_FAILURES_CONFIG_GROUP_DB, FAILING_TOGETHER_CONFIG_GROUP_DB],
 )
 PUSH_DATA_CONFIG_GROUP_DB = "data/push_data_config_group.json"
 db.register(
     PUSH_DATA_CONFIG_GROUP_DB,
-    "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.data_test_config_group_scheduling_history_push_data.latest/artifacts/public/push_data_config_group.json.zst",
+    "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.data_test_config_group_scheduling_history_push_data.latest/artifacts/public/push_data_config_group.json.zst",
     1,
 )
 
@@ -101,6 +101,7 @@ HISTORICAL_TIMESPAN = 4500
 
 JOBS_TO_CONSIDER = ("test-", "build-")
 JOBS_TO_IGNORE = (
+    "docker-image-",
     "build-docker-image-",
     "-android-hw-",
     "-awsy-",
@@ -135,10 +136,14 @@ def filter_runnables(
 
 def rename_task(task: str) -> str:
     # https://bugzilla.mozilla.org/show_bug.cgi?id=1602863
-    task = task.replace("test-linux64-", "test-linux1804-64-")
+    task = task.replace("test-linux64", "test-linux1804-64")
 
     # https://bugzilla.mozilla.org/show_bug.cgi?id=1623355
-    task = re.sub(r"android(.+)/pgo", r"android\g<1>-shippable/opt", task,)
+    task = re.sub(
+        r"android(.+)/pgo",
+        r"android\g<1>-shippable/opt",
+        task,
+    )
 
     # https://bugzilla.mozilla.org/show_bug.cgi?id=1641948
     task = task.replace(
@@ -152,6 +157,9 @@ def rename_task(task: str) -> str:
         "android-hw-p2-8-0-android-aarch64-shippable-qr/opt",
     )
 
+    # https://bugzilla.mozilla.org/show_bug.cgi?id=1650208
+    task = task.replace("-shippable", "")
+
     return task
 
 
@@ -168,7 +176,12 @@ def rename_runnables(
     elif granularity == "config_group":
         config_groups = cast(List[ConfigGroup], runnables)
         return tuple(
-            ConfigGroup((rename_task(config), Group(group.split(":")[0]),))
+            ConfigGroup(
+                (
+                    rename_task(config),
+                    Group(group.split(":")[0]),
+                )
+            )
             for config, group in config_groups
         )
     else:
@@ -336,7 +349,8 @@ def failing_together_key(item: str) -> bytes:
 
 def remove_failing_together_db(granularity: str) -> None:
     shutil.rmtree(
-        get_failing_together_db_path(granularity), ignore_errors=True,
+        get_failing_together_db_path(granularity),
+        ignore_errors=True,
     )
 
 
@@ -717,7 +731,12 @@ def generate_data(
             past_1400_pushes_types_failures,
             past_2800_pushes_types_failures,
         ) = _read_and_update_past_failures(
-            past_failures, "type", runnable, commit["types"], push_num, is_regression,
+            past_failures,
+            "type",
+            runnable,
+            commit["types"],
+            push_num,
+            is_regression,
         )
 
         (
@@ -726,7 +745,12 @@ def generate_data(
             past_1400_pushes_files_failures,
             past_2800_pushes_files_failures,
         ) = _read_and_update_past_failures(
-            past_failures, "file", runnable, commit["files"], push_num, is_regression,
+            past_failures,
+            "file",
+            runnable,
+            commit["files"],
+            push_num,
+            is_regression,
         )
 
         (
