@@ -127,8 +127,7 @@ def get_taskcluster_options():
 
 
 def get_secret(secret_id):
-    """ Return the secret value
-    """
+    """Return the secret value"""
     env_variable_name = f"BUGBUG_{secret_id}"
 
     # Try in the environment first
@@ -220,7 +219,7 @@ def download_model(model_name):
             version = "latest"
 
     path = f"{model_name}model"
-    url = f"https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.train_{model_name}.{version}/artifacts/public/{path}.zst"
+    url = f"https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.train_{model_name}.{version}/artifacts/public/{path}.zst"
     logger.info(f"Downloading {url}...")
     updated = download_check_etag(url)
     if updated:
@@ -296,8 +295,7 @@ def extract_file(path: str) -> None:
 
 
 class CustomJsonEncoder(json.JSONEncoder):
-    """ A custom Json Encoder to support Numpy types
-    """
+    """A custom Json Encoder to support Numpy types"""
 
     def default(self, obj):
         try:
