@@ -37,8 +37,8 @@ from bugbug.utils import (
 basicConfig(level=INFO)
 logger = getLogger(__name__)
 
-URL = "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.train_{model_name}.latest/artifacts/public/{file_name}"
-PAST_BUGS_BY_FUNCTION_URL = "https://community-tc.services.mozilla.com/api/index/v1/task/project.relman.bugbug.past_bugs_by_function.latest/artifacts/public/past_bugs_by_function.pickle.zst"
+URL = "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.train_{model_name}.latest/artifacts/public/{file_name}"
+PAST_BUGS_BY_FUNCTION_URL = "https://community-tc.services.mozilla.com/api/index/v1/task/project.bugbug.past_bugs_by_function.latest/artifacts/public/past_bugs_by_function.pickle.zst"
 PHAB_PROD = "prod"
 PHAB_DEV = "dev"
 
@@ -125,7 +125,15 @@ def replace_reviewers(commit_description, reviewers):
 
 
 class CommitClassifier(object):
-    def __init__(self, model_name, repo_dir, git_repo_dir, method_defect_predictor_dir):
+    def __init__(
+        self,
+        model_name: str,
+        repo_dir: str,
+        git_repo_dir: str,
+        method_defect_predictor_dir: str,
+        use_single_process: bool,
+        skip_feature_importance: bool,
+    ):
         self.model_name = model_name
         self.repo_dir = repo_dir
 
@@ -146,6 +154,9 @@ class CommitClassifier(object):
                 "8cc47f47ffb686a29324435a0151b5fabd37f865",
             )
 
+        self.use_single_process = use_single_process
+        self.skip_feature_importance = skip_feature_importance
+
         if model_name == "regressor":
             self.use_test_history = False
 
@@ -183,7 +194,7 @@ class CommitClassifier(object):
                 test_scheduling.TEST_LABEL_SCHEDULING_DB,
                 test_scheduling.PAST_FAILURES_LABEL_DB,
             )
-            self.past_failures_data = test_scheduling.get_past_failures("label")
+            self.past_failures_data = test_scheduling.get_past_failures("label", True)
 
             self.testfailure_model = download_and_load_model("testfailure")
             assert self.testfailure_model is not None
@@ -206,7 +217,10 @@ class CommitClassifier(object):
             stop=tenacity.stop_after_attempt(5),
         )(
             lambda: subprocess.run(
-                ["git", "fetch"], cwd=repo_dir, capture_output=True, check=True,
+                ["git", "fetch"],
+                cwd=repo_dir,
+                capture_output=True,
+                check=True,
             )
         )()
 
@@ -223,7 +237,9 @@ class CommitClassifier(object):
             pass
 
         repository.download_commits(
-            self.repo_dir, rev_start="children({})".format(commit["node"])
+            self.repo_dir,
+            rev_start="children({})".format(commit["node"]),
+            use_single_process=self.use_single_process,
         )
 
     def has_revision(self, hg, revision):
@@ -566,16 +582,36 @@ class CommitClassifier(object):
 
         self.update_commit_db()
 
-        with hglib.open(self.repo_dir) as hg:
-            if phabricator_deployment is not None and diff_id is not None:
+        if phabricator_deployment is not None and diff_id is not None:
+            with hglib.open(self.repo_dir) as hg:
                 self.apply_phab(hg, phabricator_deployment, diff_id)
 
                 revision = hg.log(revrange="not public()")[0].node.decode("utf-8")
 
-            # Analyze patch.
             commits = repository.download_commits(
-                self.repo_dir, rev_start=revision, save=False
+                self.repo_dir,
+                rev_start=revision,
+                save=False,
+                use_single_process=self.use_single_process,
             )
+        else:
+            commits = []
+
+            for commit in repository.get_commits():
+                if commit["node"] == revision:
+                    commits.append(commit)
+                    break
+
+            # The commit to analyze was not in our DB, let's mine it.
+            if len(commits) == 0:
+                commits = repository.download_commits(
+                    self.repo_dir,
+                    revs=[revision],
+                    save=False,
+                    use_single_process=self.use_single_process,
+                )
+
+        assert len(commits) > 0, "There are no commits to analyze"
 
         if not self.use_test_history:
             self.classify_regressor(commits)
@@ -594,7 +630,8 @@ class CommitClassifier(object):
             importance_cutoff=0.05,
         )
 
-        self.generate_feature_importance_data(probs, importance)
+        if not self.skip_feature_importance:
+            self.generate_feature_importance_data(probs, importance)
 
         with open("probs.json", "w") as f:
             json.dump(probs[0].tolist(), f)
@@ -687,7 +724,13 @@ class CommitClassifier(object):
         assert stop_hash is not None
 
         p = subprocess.run(
-            ["git", "rev-list", "-n", "1", "HEAD",],
+            [
+                "git",
+                "rev-list",
+                "-n",
+                "1",
+                "HEAD",
+            ],
             check=True,
             capture_output=True,
             cwd=self.git_repo_dir,
@@ -774,11 +817,26 @@ def main():
         "--method_defect_predictor_dir",
         help="Path where the git repository will be cloned.",
     )
+    parser.add_argument(
+        "--use-single-process",
+        action="store_true",
+        help="Whether to use a single process.",
+    )
+    parser.add_argument(
+        "--skip-feature-importance",
+        action="store_true",
+        help="Whether to skip feature importance calculation.",
+    )
 
     args = parser.parse_args()
 
     classifier = CommitClassifier(
-        args.model, args.repo_dir, args.git_repo_dir, args.method_defect_predictor_dir
+        args.model,
+        args.repo_dir,
+        args.git_repo_dir,
+        args.method_defect_predictor_dir,
+        args.use_single_process,
+        args.skip_feature_importance,
     )
     classifier.classify(
         args.revision, args.phabricator_deployment, args.diff_id, args.runnable_jobs
